@@ -201,8 +201,7 @@ pub fn solve(
         (2018, 21, 2) => to_stringer(year2018::day21::part2, input_string),
         (2018, 22, 1) => to_stringer(year2018::day22::part1, input_string),
         (2018, 22, 2) => to_stringer(year2018::day22::part2, input_string),
-        (2018, 23, 1) => to_stringer(year2018::day23::part1, input_string),
-        (2018, 23, 2) => to_stringer(year2018::day23::part2, input_string),
+        (2018, 23, _) => to_stringer_input(year2018::day23::solve, &mut input),
         (2018, 24, 1) => to_stringer(year2018::day24::part1, input_string),
         (2018, 24, 2) => to_stringer(year2018::day24::part2, input_string),
         (2018, 25, 1) => to_stringer(year2018::day25::part1, input_string),
